import "./tasks/fastqc.wdl" as fastqc
import "./tasks/trimmomatic.wdl" as trimmomatic
import "./tasks/tophat2.wdl" as tophat2
import "./tasks/cuffdiff2.wdl" as cuffdiff2

workflow {{ project_name }} {
	File read1
	File read2
	File adapter
	String baseout

	File gtf
	File genome_directory
	String idx_prefix
	
	scatter ( read in [read1, read2]) {
		call fastqc.qc as fastqc {input: read=read}
	}
	
	call trimmomatic.trimmomatic as trimmomatic {
		input: baseout=baseout, read1=read1, read2=read2, adapter=adapter
	}

	call tophat2.tophat2 as tophat2 {
		input: baseout=baseout, read_1P=trimmomatic.read_1p, read_2P=trimmomatic.read_2p, gtf=gtf, genome_directory=genome_directory, idx_prefix=idx_prefix
	}

	call cuffdiff2.cuffdiff2 as cuffdiff2 {
		input: gtf = gtf, bam = tophat2.accepted_hits, genome_directory=genome_directory, idx_prefix=idx_prefix, baseout=baseout
	}
        
	output {
		Array[File] fastqc_html = fastqc.html
		Array[File] fastqc_zip = fastqc.zip
                File fastq_1p = trimmomatic.read_1p
		File fastq_2p = trimmomatic.read_2p
                File bam = tophat2.accepted_hits
		File unmapped_bam = tophat2.unmapped_bam
                File isoforms_count = cuffdiff2.isoforms_count
		File genes_count = cuffdiff2.genes_count
		File cds_count = cuffdiff2.cds_count
		File isoforms_fpkm = cuffdiff2.isoforms_fpkm
		File genes_fpkm = cuffdiff2.genes_fpkm
		File cds_fpkm = cuffdiff2.cds_fpkm
	}
}


